@@ -308,54 +308,6 @@ cancel_cb (SimpleScan *ui)
 }
 
 
-static gboolean
-save_book_by_extension (GFile *file, GError **error)
-{
-    gboolean result;
-    gchar *uri, *uri_lower;
-
-    uri = g_file_get_uri (file);
-    uri_lower = g_utf8_strdown (uri, -1);
-    if (g_str_has_suffix (uri_lower, ".pdf"))
-        result = book_save (book, "pdf", file, error);
-    else if (g_str_has_suffix (uri_lower, ".ps"))
-        result = book_save (book, "ps", file, error);
-    else if (g_str_has_suffix (uri_lower, ".png"))
-        result = book_save (book, "png", file, error);
-    else if (g_str_has_suffix (uri_lower, ".tif") || g_str_has_suffix (uri_lower, ".tiff"))
-        result = book_save (book, "tiff", file, error);
-    else
-        result = book_save (book, "jpeg", file, error);
-
-    g_free (uri);
-    g_free (uri_lower);
-
-    return result;
-}
-
-
-static void
-save_cb (SimpleScan *ui, const gchar *uri)
-{
-    GError *error = NULL;
-    GFile *file;
-
-    g_debug ("Saving to '%s'", uri);
-
-    file = g_file_new_for_uri (uri);
-    if (!save_book_by_extension (file, &error)) {
-        g_warning ("Error saving file: %s", error->message);
-        ui_show_error (ui,
-                       /* Title of error dialog when save failed */
-                       _("Failed to save file"),
-                       error->message,
-                       FALSE);
-        g_error_free (error);
-    }
-    g_object_unref (file);
-}
-
-
 static gchar *
 get_temporary_filename (const gchar *prefix, const gchar *extension)
 {
@@ -628,7 +580,6 @@ main (int argc, char **argv)
     book = ui_get_book (ui);
     g_signal_connect (ui, "start-scan", G_CALLBACK (scan_cb), NULL);
     g_signal_connect (ui, "stop-scan", G_CALLBACK (cancel_cb), NULL);
-    g_signal_connect (ui, "save", G_CALLBACK (save_cb), NULL);
     g_signal_connect (ui, "email", G_CALLBACK (email_cb), NULL);
     g_signal_connect (ui, "quit", G_CALLBACK (quit_cb), NULL);
 
